@@ -1,6 +1,7 @@
 package resource
 
 import (
+	"context"
 	"fmt"
 	"os"
 
@@ -15,16 +16,15 @@ import (
 
 	imageregistryapiv1 "github.com/openshift/api/imageregistry/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
-
 	imageregistryv1listers "github.com/openshift/client-go/imageregistry/listers/imageregistry/v1"
-	"github.com/openshift/cluster-image-registry-operator/defaults"
-	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
+
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 )
 
 var (
 	defaultSuspend                          = false
 	defaultSchedule                         = "0 0 * * *"
-	defaultStartingDeadlineSeconds    int64 = 60
+	defaultStartingDeadlineSeconds    int64 = 3600
 	defaultFailedJobsHistoryLimit     int32 = 3
 	defaultSuccessfulJobsHistoryLimit int32 = 3
 	defaultKeepTagRevisions                 = 3
@@ -47,10 +47,9 @@ type generatorPrunerCronJob struct {
 	client       batchset.BatchV1beta1Interface
 	prunerLister imageregistryv1listers.ImagePrunerLister
 	configLister imageregistryv1listers.ConfigLister
-	cr           *imageregistryapiv1.ImagePruner
 }
 
-func newGeneratorPrunerCronJob(lister batchlisters.CronJobNamespaceLister, client batchset.BatchV1beta1Interface, prunerLister imageregistryv1listers.ImagePrunerLister, configLister imageregistryv1listers.ConfigLister, params *parameters.Globals) *generatorPrunerCronJob {
+func newGeneratorPrunerCronJob(lister batchlisters.CronJobNamespaceLister, client batchset.BatchV1beta1Interface, prunerLister imageregistryv1listers.ImagePrunerLister, configLister imageregistryv1listers.ConfigLister) *generatorPrunerCronJob {
 	return &generatorPrunerCronJob{
 		lister:       lister,
 		client:       client,
@@ -63,14 +62,6 @@ func (gcj *generatorPrunerCronJob) Type() runtime.Object {
 	return &batchapi.CronJob{}
 }
 
-func (gcj *generatorPrunerCronJob) GetGroup() string {
-	return batchapi.GroupName
-}
-
-func (gcj *generatorPrunerCronJob) GetResource() string {
-	return "batches"
-}
-
 func (gcj *generatorPrunerCronJob) GetNamespace() string {
 	return defaults.ImageRegistryOperatorNamespace
 }
@@ -111,6 +102,18 @@ func (gcj *generatorPrunerCronJob) expected() (runtime.Object, error) {
 							Affinity:           gcj.getAffinity(cr),
 							NodeSelector:       gcj.getNodeSelector(cr),
 							Tolerations:        gcj.getTolerations(cr),
+							Volumes: []kcorev1.Volume{
+								{
+									Name: "serviceca",
+									VolumeSource: kcorev1.VolumeSource{
+										ConfigMap: &kcorev1.ConfigMapVolumeSource{
+											LocalObjectReference: kcorev1.LocalObjectReference{
+												Name: "serviceca",
+											},
+										},
+									},
+								},
+							},
 							Containers: []kcorev1.Container{
 								{
 									Image:                    os.Getenv("IMAGE_PRUNER"),
@@ -122,12 +125,19 @@ func (gcj *generatorPrunerCronJob) expected() (runtime.Object, error) {
 										"adm",
 										"prune",
 										"images",
-										"--certificate-authority=/var/run/secrets/kubernetes.io/serviceaccount/service-ca.crt",
+										"--certificate-authority=/var/run/configmaps/serviceca/service-ca.crt",
 										fmt.Sprintf("--keep-tag-revisions=%d", gcj.getKeepTagRevisions(cr)),
 										fmt.Sprintf("--keep-younger-than=%s", gcj.getKeepYoungerThan(cr)),
 										fmt.Sprintf("--prune-registry=%t", gcj.getPruneRegistry(rcr)),
 										"--confirm=true",
 									},
+									VolumeMounts: []kcorev1.VolumeMount{
+										{
+											Name:      "serviceca",
+											MountPath: "/var/run/configmaps/serviceca",
+											ReadOnly:  true,
+										},
+									},
 								},
 							},
 						},
@@ -213,8 +223,11 @@ func (gcj *generatorPrunerCronJob) getKeepTagRevisions(cr *imageregistryapiv1.Im
 }
 
 func (gcj *generatorPrunerCronJob) getKeepYoungerThan(cr *imageregistryapiv1.ImagePruner) string {
+	if cr.Spec.KeepYoungerThanDuration != nil {
+		return cr.Spec.KeepYoungerThanDuration.Duration.String()
+	}
 	if cr.Spec.KeepYoungerThan != nil {
-		return fmt.Sprintf("%s", cr.Spec.KeepYoungerThan)
+		return cr.Spec.KeepYoungerThan.String()
 	}
 	return defaultKeepYoungerThan
 }
@@ -225,19 +238,24 @@ func (gcj *generatorPrunerCronJob) Get() (runtime.Object, error) {
 
 func (gcj *generatorPrunerCronJob) Create() (runtime.Object, error) {
 	return commonCreate(gcj, func(obj runtime.Object) (runtime.Object, error) {
-
-		return gcj.client.CronJobs(gcj.GetNamespace()).Create(obj.(*batchapi.CronJob))
+		return gcj.client.CronJobs(gcj.GetNamespace()).Create(
+			context.TODO(), obj.(*batchapi.CronJob), metav1.CreateOptions{},
+		)
 	})
 }
 
 func (gcj *generatorPrunerCronJob) Update(o runtime.Object) (runtime.Object, bool, error) {
 	return commonUpdate(gcj, o, func(obj runtime.Object) (runtime.Object, error) {
-		return gcj.client.CronJobs(gcj.GetNamespace()).Update(obj.(*batchapi.CronJob))
+		return gcj.client.CronJobs(gcj.GetNamespace()).Update(
+			context.TODO(), obj.(*batchapi.CronJob), metav1.UpdateOptions{},
+		)
 	})
 }
 
-func (gcj *generatorPrunerCronJob) Delete(opts *metav1.DeleteOptions) error {
-	return gcj.client.CronJobs(gcj.GetNamespace()).Delete(gcj.GetName(), opts)
+func (gcj *generatorPrunerCronJob) Delete(opts metav1.DeleteOptions) error {
+	return gcj.client.CronJobs(gcj.GetNamespace()).Delete(
+		context.TODO(), gcj.GetName(), opts,
+	)
 }
 
 func (gcj *generatorPrunerCronJob) Owned() bool {
