@@ -1,14 +1,15 @@
 package resource
 
 import (
+	"context"
+
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	coreset "k8s.io/client-go/kubernetes/typed/core/v1"
 	corelisters "k8s.io/client-go/listers/core/v1"
 
-	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
-	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 )
 
 var _ Mutator = &generatorServiceAccount{}
@@ -20,12 +21,12 @@ type generatorServiceAccount struct {
 	namespace string
 }
 
-func newGeneratorServiceAccount(lister corelisters.ServiceAccountNamespaceLister, client coreset.CoreV1Interface, params *parameters.Globals, cr *imageregistryv1.Config) *generatorServiceAccount {
+func newGeneratorServiceAccount(lister corelisters.ServiceAccountNamespaceLister, client coreset.CoreV1Interface) *generatorServiceAccount {
 	return &generatorServiceAccount{
 		lister:    lister,
 		client:    client,
-		name:      params.Pod.ServiceAccount,
-		namespace: params.Deployment.Namespace,
+		name:      defaults.ServiceAccountName,
+		namespace: defaults.ImageRegistryOperatorNamespace,
 	}
 }
 
@@ -33,14 +34,6 @@ func (gsa *generatorServiceAccount) Type() runtime.Object {
 	return &corev1.ServiceAccount{}
 }
 
-func (gsa *generatorServiceAccount) GetGroup() string {
-	return corev1.GroupName
-}
-
-func (gsa *generatorServiceAccount) GetResource() string {
-	return "serviceaccounts"
-}
-
 func (gsa *generatorServiceAccount) GetNamespace() string {
 	return gsa.namespace
 }
@@ -66,18 +59,24 @@ func (gsa *generatorServiceAccount) Get() (runtime.Object, error) {
 
 func (gsa *generatorServiceAccount) Create() (runtime.Object, error) {
 	return commonCreate(gsa, func(obj runtime.Object) (runtime.Object, error) {
-		return gsa.client.ServiceAccounts(gsa.GetNamespace()).Create(obj.(*corev1.ServiceAccount))
+		return gsa.client.ServiceAccounts(gsa.GetNamespace()).Create(
+			context.TODO(), obj.(*corev1.ServiceAccount), metav1.CreateOptions{},
+		)
 	})
 }
 
 func (gsa *generatorServiceAccount) Update(o runtime.Object) (runtime.Object, bool, error) {
 	return commonUpdate(gsa, o, func(obj runtime.Object) (runtime.Object, error) {
-		return gsa.client.ServiceAccounts(gsa.GetNamespace()).Update(obj.(*corev1.ServiceAccount))
+		return gsa.client.ServiceAccounts(gsa.GetNamespace()).Update(
+			context.TODO(), obj.(*corev1.ServiceAccount), metav1.UpdateOptions{},
+		)
 	})
 }
 
-func (gsa *generatorServiceAccount) Delete(opts *metav1.DeleteOptions) error {
-	return gsa.client.ServiceAccounts(gsa.GetNamespace()).Delete(gsa.GetName(), opts)
+func (gsa *generatorServiceAccount) Delete(opts metav1.DeleteOptions) error {
+	return gsa.client.ServiceAccounts(gsa.GetNamespace()).Delete(
+		context.TODO(), gsa.GetName(), opts,
+	)
 }
 
 func (g *generatorServiceAccount) Owned() bool {
